Drummer class

Constructors

Drummer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteOff(double amp) → void
noteOn(double instrument, double amp) → void
Trigger a drum sound. instrument frequency value as if MIDI note number. General MIDI drum instrument numbers.
render(int frameCount) List<double>
setPitch(double pitch) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited