Saxophone class

Constructors

Saxophone()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

controlChange(int number, double value) → void
Control change parameters:
init(double freq) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteOn(double freq, double amp) → void
render(int frameCount) List<double>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited