Shakers class

Constructors

Shakers([int type = 0])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

controlChange(int number, double value) → void
Control change parameters:
init(int type) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteOn(double instrument, double amp) → void
render(int frameCount) List<double>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bambooChimes → const int
bigRocks → const int
cabasa → const int
cokeCan → const int
crunch → const int
dimeMug → const int
francMug → const int
guiro → const int
littleRocks → const int
maraca → const int
nextMug → const int
nickleMug → const int
pennyMug → const int
pesoMug → const int
quarterMug → const int
sandPaper → const int
sekere → const int
sleighBells → const int
sticks → const int
tambourine → const int
tunedBambooChimes → const int
waterDrops → const int
wrench → const int